### R code from vignette source 'demoARAMIS.Rnw'

###################################################
### code chunk number 1: demoARAMIS.Rnw:20-22
###################################################
options(width = 80)
set.seed(17)


###################################################
### code chunk number 2: init
###################################################
library(ARAMIS)


###################################################
### code chunk number 3: AIS
###################################################
ais <- AIS(N=1000,
                niter=10,
                p=2,
                target= targetBanana(),
                initialize=uniInit(),
                mixture= mclustMix())


###################################################
### code chunk number 4: ais-plot
###################################################
par(mfrow=c(1,2))
plot(ais,whichOne=1L:2L)


###################################################
### code chunk number 5: AMIS
###################################################
amis <- AMIS(N=1000,
                      niter=10,
                      p=2,
                      target=targetBanana(b=0.1),
                      initialize= amisInit(maxit=5000),
                       mixture=mclustMix())


###################################################
### code chunk number 6: amis-plot
###################################################
par(mfrow=c(1,2))
plot(amis,whichOne=1L:2L,n=300)


###################################################
### code chunk number 7: show
###################################################
showClass("ISO")
summary(amis)


###################################################
### code chunk number 8: exampleOfSubsetting
###################################################
amis$ESS
ais[["ESS"]]


###################################################
### code chunk number 9: meanVar
###################################################
sqr <- function(x){x^2} 
mean(amis,fun=sqr) - mean(amis)^2
var(amis)


###################################################
### code chunk number 10: seed
###################################################
set.seed(1264649575)


###################################################
### code chunk number 11: galambos
###################################################
# Galambos Copula
# a : location parameter GEV
# b : scale parameter GEV
# s : shape parameter GEV
# theta : copula's parameter

galambosCop <- function(a=0,b=1,s=0,theta=1.5,copula=galambosCopula){

	require("copula")
	require("evd")
	
	Cop <- copula(theta)
	
	function(xx){
		
		U <- pgev(xx,loc=a, scale=b,shape=s) 
		# numerical stability can be a issue...
		U[U>1-sqrt(.Machine$double.eps)] <- 1-sqrt(.Machine$double.eps)
		U[U<sqrt(.Machine$double.eps)] <- sqrt(.Machine$double.eps)
		
		if(length(dim(xx)>1)){
			trgt <- log(dCopula(U,Cop))+
			           rowSums(apply(xx,2,function(x)
			                      dgev(x,loc=a, scale=b,shape = s,log=TRUE)))
			}else{
				trgt <- log(dCopula(U,Cop))+
				             sum(dgev(xx,loc=a, scale=b,shape=s,log=TRUE))
				}
		
		trgt
		
		}	
	}


###################################################
### code chunk number 12: galambosClose
###################################################
toughCop <- galambosCop()
ls(envir=environment(toughCop))
get("theta",envir=environment(toughCop))


###################################################
### code chunk number 13: galambosAMIS
###################################################

resCop <- AMIS(N=c(500,1000,500),
                           niter=c(10,50),
                           p=2,
                          target=toughCop,
                           initialize= amisInit(maxit=5000),
                           mixture=mclustMix())


plot(resCop,whichOne=3L, xlim=c(-3,5),ylim=c(-3,5),N=17000)



###################################################
### code chunk number 14: parallel
###################################################
trgt <- targetBanana(b=0.1)
mxtr <- mclustMix()
system.time(amis <- AMIS(N=1000,niter=10,p=2,target=trgt,mixture=mxtr))	
invisible(gc())
system.time(amisMC <- AMIS(N=1000,niter=10,p=2,target=trgt,mixture=mxtr,parallel="multicore",nCores=2))	
invisible(gc())
system.time(amisSN <- AMIS(N=1000,niter=10,p=2,target=trgt,mixture=mxtr,parallel="snow",nCores=2))


summary(amis)
summary(amisMC)
summary(amisSN)
	
par(mfrow=c(1,3))
plot(amis,whichOne=1L)
plot(amisMC,whichOne=1L)
plot(amisSN,whichOne=1L)



###################################################
### code chunk number 15: sessionInfo
###################################################
toLatex(sessionInfo())


